Enum Event

pub enum Event<T: Config> {
Show 30 variants AuthorEnlisted { author: Author<T>, collateral: AuthorAsset<T>, }, AuthorResigned { author: Author<T>, released: AuthorAsset<T>, }, AuthorCollateralRaised { author: Author<T>, raised: AuthorAsset<T>, }, AuthorTotalCollateral { author: Author<T>, collateral: AuthorAsset<T>, }, AuthorFunded { author: Author<T>, backer: Backer<T>, amount: AuthorAsset<T>, }, InspectAuthorFund { author: Author<T>, backer: Backer<T>, amount: AuthorAsset<T>, }, InspectFund { author: Author<T>, funder: Funder<T>, amount: AuthorAsset<T>, }, IndexFunded { index: IndexDigest<T>, backer: Backer<T>, amount: AuthorAsset<T>, }, InspectIndexFund { index: IndexDigest<T>, backer: Backer<T>, amount: AuthorAsset<T>, }, PoolFunded { pool: PoolDigest<T>, backer: Backer<T>, amount: AuthorAsset<T>, }, InspectPoolFund { pool: PoolDigest<T>, backer: Backer<T>, amount: AuthorAsset<T>, }, AuthorDrawn { author: Author<T>, backer: Backer<T>, amount: AuthorAsset<T>, }, IndexDrawn { index: IndexDigest<T>, backer: Backer<T>, amount: AuthorAsset<T>, }, PoolDrawn { pool: PoolDigest<T>, backer: Backer<T>, amount: AuthorAsset<T>, }, ScheduledRewards { author: Author<T>, rewards: Vec<(BlockNumberFor<T>, AuthorAsset<T>)>, }, ScheduledPenalties { author: Author<T>, penalties: Vec<(BlockNumberFor<T>, Ratio<T>)>, }, AuthorRewardScheduled { author: Author<T>, amount: AuthorAsset<T>, at: BlockNumberFor<T>, }, AuthorPenaltyScheduled { author: Author<T>, factor: Ratio<T>, at: BlockNumberFor<T>, }, AuthorStatus { author: Author<T>, status: AuthorStatus, }, AuthorAtRisk { author: Author<T>, status: AuthorStatus, until: BlockNumberFor<T>, }, AuthorPenaltyForgiven { author: Author<T>, factor: Ratio<T>, }, AuthorRewardReclaimed { author: Author<T>, amount: AuthorAsset<T>, }, AuthorTotalHold { author: Author<T>, value: AuthorAsset<T>, }, ElectionPrepared { elects: Vec<Author<T>>, }, ElectionFailed { error: DispatchError, }, IndexCreated { index: IndexDigest<T>, }, PoolCreated { pool: PoolDigest<T>, commission: Commission<T>, manager: T::AccountId, }, PoolManager { digest: PoolDigest<T>, manager: T::AccountId, }, PoolSlotShare { pool: PoolDigest<T>, slots: (PoolDigest<T>, Shares<T>), }, GenesisConfigUpdated(ForceGenesisConfig<T>), // some variants omitted
}
The Event enum of this pallet

Variants



AuthorEnlisted

Emitted when an account successfully enrolls, by enlisting itself as an author by locking the required collateral for the role.

Fields

author: Author<T>
collateral: AuthorAsset<T>


AuthorResigned

Emitted when an author voluntarily resigns from the role, regains their collateral and exits active participation.

Fields

author: Author<T>
released: AuthorAsset<T>


AuthorCollateralRaised

Emitted when an author’s total collateral is incremented i.e., additional collateral being added.

Fields

author: Author<T>
raised: AuthorAsset<T>


AuthorTotalCollateral

Emitted when the total collateral of an author is queried.

Fields

author: Author<T>
collateral: AuthorAsset<T>


AuthorFunded

Emitted when a backer funds to an author via any funding mechanism such as direct, indexed and pooled.

Fields

author: Author<T>
backer: Backer<T>
amount: AuthorAsset<T>


InspectAuthorFund

Emitted when a backer queries their fund that is commited to a author directly.

Fields

author: Author<T>
backer: Backer<T>
amount: AuthorAsset<T>


InspectFund

Emitted when a backer queries their fund that is commited to an author through Direct, Index or Pool based funding mechanism.

Fields

author: Author<T>
funder: Funder<T>
amount: AuthorAsset<T>


IndexFunded

Emitted when a backer funds authors through an index-based funding mechanism.

Fields

index: IndexDigest<T>
backer: Backer<T>
amount: AuthorAsset<T>


InspectIndexFund

Emitted when a backer queries their fund that is commited to an index-based funding mechanism.

Fields

index: IndexDigest<T>
backer: Backer<T>
amount: AuthorAsset<T>


PoolFunded

Emitted when a backer funds authors through an pool-based funding mechanism.

Fields

pool: PoolDigest<T>
backer: Backer<T>
amount: AuthorAsset<T>


InspectPoolFund

Emitted when a backer queries their fund that is commited to an pool-based funding mechanism.

Fields

pool: PoolDigest<T>
backer: Backer<T>
amount: AuthorAsset<T>


AuthorDrawn

Emitted when previously committed funds are successfully released from an author back to the backer.

Fields

author: Author<T>
backer: Backer<T>
amount: AuthorAsset<T>


IndexDrawn

Emitted when previously committed funds are successfully released from an index back to the backer.

Fields

index: IndexDigest<T>
backer: Backer<T>
amount: AuthorAsset<T>


PoolDrawn

Emitted when previously committed funds are successfully released from an pool back to the backer.

Fields

pool: PoolDigest<T>
backer: Backer<T>
amount: AuthorAsset<T>


ScheduledRewards

Emitted when scheduled rewards are queried for an author, including one or more future block numbers at which the rewards will be applied.

Fields

author: Author<T>
rewards: Vec<(BlockNumberFor<T>, AuthorAsset<T>)>


ScheduledPenalties

Emitted when scheduled penalties are queried for an author, including one or more future block numbers at which the penalties will be enforced.

Fields

author: Author<T>
penalties: Vec<(BlockNumberFor<T>, Ratio<T>)>


AuthorRewardScheduled

Emitted when a reward is applied or scheduled to an author at a specific block.

Fields

author: Author<T>
amount: AuthorAsset<T>
at: BlockNumberFor<T>


AuthorPenaltyScheduled

Emitted when a penalty is applied or scheduled to an author at a specific block.

Fields

author: Author<T>
factor: Ratio<T>
at: BlockNumberFor<T>


AuthorStatus

Emitted when an author’s lifecycle status changes, including transitions between probation, active, or other defined states.

Fields

author: Author<T>


AuthorAtRisk

Emitted when an author’s status is at risk until a specified block, due to negative behavior, affecting either permanence or probation state.

Fields

author: Author<T>
until: BlockNumberFor<T>


AuthorPenaltyForgiven

Emitted when a previously scheduled penalty for an author is forgiven.

Fields

author: Author<T>
factor: Ratio<T>


AuthorRewardReclaimed

Emitted when a previously scheduled reward for an author is reclaimed.

Fields

author: Author<T>
amount: AuthorAsset<T>


AuthorTotalHold

Emitted when the held (locked) balance of an author is updated or queried.

Fields

author: Author<T>
value: AuthorAsset<T>


ElectionPrepared

Emitted when an election preparation completes successfully and elected authors are stored for runtime-usage.

Fields

elects: Vec<Author<T>>


ElectionFailed

Emitted when an election preparation fails to complete successfully.

Fields

error: DispatchError


IndexCreated

Emitted when a new funding index is created and registered.

Fields

index: IndexDigest<T>


PoolCreated

Emitted when a new funding pool is created with a specified commission and an assigned pool manager.

Fields

pool: PoolDigest<T>
commission: Commission<T>
manager: T::AccountId


PoolManager

Emitted when management ownership of a funding pool is transferred.

Fields

digest: PoolDigest<T>
manager: T::AccountId


PoolSlotShare

Emitted when a slot share weight within a pool are updated.

Fields

pool: PoolDigest<T>
slots: (PoolDigest<T>, Shares<T>)


GenesisConfigUpdated(ForceGenesisConfig<T>)

A genesis config parameter was updated forcefully.