Type Alias MaxElected

pub type MaxElected<T: Config> = StorageValue<_GeneratedPrefixForStorageMaxElected<T>, u32, ValueQuery>;
The upper bound on the number of authors that can be elected in a single election round.

Behavior

Example

If MaxElected = 50, the election will never store more than 50 authors, even if the algorithm produces 80 winners.

Storage type is [StorageValue] with value type u32.

Aliased Type

pub struct MaxElected<T: Config>(/* private fields */);