Type Alias MaxExposure

pub type MaxExposure<T: Config> = StorageValue<_GeneratedPrefixForStorageMaxExposure<T>, AuthorAsset<T>, ValueQuery>;
Global Maximum exposure allowed globally per funding operation.

Prevents a single funding-instance from over-concentrating funding or creating systemic risk.

This is ambiguous in pool and index contexts as it only represents how much the backer is willing to commit at a transaction, not specific to what scheme.

Storage type is [StorageValue] with value type AuthorAsset < T >.

Aliased Type

pub struct MaxExposure<T: Config>(/* private fields */);