Type Alias PenaltiesUntil

pub type PenaltiesUntil<T: Config> = StorageValue<_GeneratedPrefixForStoragePenaltiesUntil<T>, BlockNumberFor<T>, ValueQuery>;
Tracks the latest block number until which author penalties are scheduled.

Ensures efficient access to pending penalties without scanning irrelevant blocks.

Must not be updated by governance manually, as its a runtime inferred value and not a genesis configurable value.

Storage type is [StorageValue] with value type BlockNumberFor < T >.

Aliased Type

pub struct PenaltiesUntil<T: Config>(/* private fields */);