Type Alias RewardsUntil

pub type RewardsUntil<T: Config> = StorageValue<_GeneratedPrefixForStorageRewardsUntil<T>, BlockNumberFor<T>, ValueQuery>;
Tracks the latest block number until which author rewards are scheduled.

Enables efficient scanning for pending rewards by limiting iteration to blocks up to RewardsUntil.

Must not be updated by governance manually, as its a runtime inferred value and not a genesis configurable value.

Storage type is [StorageValue] with value type BlockNumberFor < T >.

Aliased Type

pub struct RewardsUntil<T: Config>(/* private fields */);