pub enum Event<T: Config> {
Show 30 variants
AuthorEnlisted {
author: Author<T>,
collateral: AuthorAsset<T>,
},
AuthorResigned {
author: Author<T>,
released: AuthorAsset<T>,
},
AuthorCollateralRaised {
author: Author<T>,
raised: AuthorAsset<T>,
},
AuthorTotalCollateral {
author: Author<T>,
collateral: AuthorAsset<T>,
},
AuthorFunded {
author: Author<T>,
backer: Backer<T>,
amount: AuthorAsset<T>,
},
InspectAuthorFund {
author: Author<T>,
backer: Backer<T>,
amount: AuthorAsset<T>,
},
InspectFund {
author: Author<T>,
funder: Funder<T>,
amount: AuthorAsset<T>,
},
IndexFunded {
index: IndexDigest<T>,
backer: Backer<T>,
amount: AuthorAsset<T>,
},
InspectIndexFund {
index: IndexDigest<T>,
backer: Backer<T>,
amount: AuthorAsset<T>,
},
PoolFunded {
pool: PoolDigest<T>,
backer: Backer<T>,
amount: AuthorAsset<T>,
},
InspectPoolFund {
pool: PoolDigest<T>,
backer: Backer<T>,
amount: AuthorAsset<T>,
},
AuthorDrawn {
author: Author<T>,
backer: Backer<T>,
amount: AuthorAsset<T>,
},
IndexDrawn {
index: IndexDigest<T>,
backer: Backer<T>,
amount: AuthorAsset<T>,
},
PoolDrawn {
pool: PoolDigest<T>,
backer: Backer<T>,
amount: AuthorAsset<T>,
},
ScheduledRewards {
author: Author<T>,
rewards: Vec<(BlockNumberFor<T>, AuthorAsset<T>)>,
},
ScheduledPenalties {
author: Author<T>,
penalties: Vec<(BlockNumberFor<T>, Ratio<T>)>,
},
AuthorRewardScheduled {
author: Author<T>,
amount: AuthorAsset<T>,
at: BlockNumberFor<T>,
},
AuthorPenaltyScheduled {
author: Author<T>,
factor: Ratio<T>,
at: BlockNumberFor<T>,
},
AuthorStatus {
author: Author<T>,
status: AuthorStatus,
},
AuthorAtRisk {
author: Author<T>,
status: AuthorStatus,
until: BlockNumberFor<T>,
},
AuthorPenaltyForgiven {
author: Author<T>,
factor: Ratio<T>,
},
AuthorRewardReclaimed {
author: Author<T>,
amount: AuthorAsset<T>,
},
AuthorTotalHold {
author: Author<T>,
value: AuthorAsset<T>,
},
ElectionPrepared {
elects: Vec<Author<T>>,
},
ElectionFailed {
error: DispatchError,
},
IndexCreated {
index: IndexDigest<T>,
},
PoolCreated {
pool: PoolDigest<T>,
commission: Commission<T>,
manager: T::AccountId,
},
PoolManager {
digest: PoolDigest<T>,
manager: T::AccountId,
},
PoolSlotShare {
pool: PoolDigest<T>,
slots: (PoolDigest<T>, Shares<T>),
},
GenesisConfigUpdated(ForceGenesisConfig<T>),
// some variants omitted
}Expand description
The Event enum of this pallet
Variants
AuthorEnlisted
Emitted when an account successfully enrolls, by enlisting itself as an author by locking the required collateral for the role.
AuthorResigned
Emitted when an author voluntarily resigns from the role, regains their collateral and exits active participation.
AuthorCollateralRaised
Emitted when an author’s total collateral is incremented i.e., additional collateral being added.
AuthorTotalCollateral
Emitted when the total collateral of an author is queried.
AuthorFunded
Emitted when a backer funds to an author via any funding mechanism such as direct, indexed and pooled.
InspectAuthorFund
Emitted when a backer queries their fund that is commited to a author directly.
InspectFund
Emitted when a backer queries their fund that is commited to an author through Direct, Index or Pool based funding mechanism.
IndexFunded
Emitted when a backer funds authors through an index-based funding mechanism.
InspectIndexFund
Emitted when a backer queries their fund that is commited to an index-based funding mechanism.
PoolFunded
Emitted when a backer funds authors through an pool-based funding mechanism.
InspectPoolFund
Emitted when a backer queries their fund that is commited to an pool-based funding mechanism.
AuthorDrawn
Emitted when previously committed funds are successfully released from an author back to the backer.
IndexDrawn
Emitted when previously committed funds are successfully released from an index back to the backer.
PoolDrawn
Emitted when previously committed funds are successfully released from an pool back to the backer.
ScheduledRewards
Emitted when scheduled rewards are queried for an author, including one or more future block numbers at which the rewards will be applied.
ScheduledPenalties
Emitted when scheduled penalties are queried for an author, including one or more future block numbers at which the penalties will be enforced.
AuthorRewardScheduled
Emitted when a reward is applied or scheduled to an author at a specific block.
AuthorPenaltyScheduled
Emitted when a penalty is applied or scheduled to an author at a specific block.
AuthorStatus
Emitted when an author’s lifecycle status changes, including transitions between probation, active, or other defined states.
AuthorAtRisk
Emitted when an author’s status is at risk until a specified block, due to negative behavior, affecting either permanence or probation state.
AuthorPenaltyForgiven
Emitted when a previously scheduled penalty for an author is forgiven.
AuthorRewardReclaimed
Emitted when a previously scheduled reward for an author is reclaimed.
AuthorTotalHold
Emitted when the held (locked) balance of an author is updated or queried.
ElectionPrepared
Emitted when an election preparation completes successfully and elected authors are stored for runtime-usage.
ElectionFailed
Emitted when an election preparation fails to complete successfully.
Fields
error: DispatchErrorIndexCreated
Emitted when a new funding index is created and registered.
Fields
index: IndexDigest<T>PoolCreated
Emitted when a new funding pool is created with a specified commission and an assigned pool manager.
PoolManager
Emitted when management ownership of a funding pool is transferred.
Emitted when a slot share weight within a pool are updated.
GenesisConfigUpdated(ForceGenesisConfig<T>)
A genesis config parameter was updated forcefully.