pub type MinCollateral<T: Config> = StorageValue<_GeneratedPrefixForStorageMinCollateral<T>, AuthorAsset<T>, ValueQuery>;Expand description
Global Minimum collateral required for any author.
Must not be set to zero, else collateral query functions will fail, as there will be no actual commitment.
Ensures authors maintain sufficient stake or backing for network security.
Storage type is [StorageValue] with value type AuthorAsset < T >.
Aliased Type
pub struct MinCollateral<T: Config>(/* private fields */);