pub type MinFund<T: Config> = StorageValue<_GeneratedPrefixForStorageMinFund<T>, AuthorAsset<T>, ValueQuery>;Expand description
Global Minimum funding required globally per funding operation.
Ensures authors meet base economic requirements for participation.
This is ambiguous in pool and index contexts as it only represents how
much the backer is willing to commit at a transaction, not specific to what scheme.
Storage type is [StorageValue] with value type AuthorAsset < T >.
Aliased Type
pub struct MinFund<T: Config>(/* private fields */);