pub type PenaltiesBuffer<T: Config> = StorageValue<_GeneratedPrefixForStoragePenaltiesBuffer<T>, BlockNumberFor<T>, ValueQuery>;Expand description
Buffer period in blocks before a penalty can be applied.
Provides temporal separation for enforcement and ensures deterministic scheduling of penalties.
Storage type is [StorageValue] with value type BlockNumberFor < T >.
Aliased Type
pub struct PenaltiesBuffer<T: Config>(/* private fields */);