pub type RewardsBuffer<T: Config> = StorageValue<_GeneratedPrefixForStorageRewardsBuffer<T>, BlockNumberFor<T>, ValueQuery>;Expand description
Buffer period in blocks before a reward can be applied.
Used to defer rewards and ensure orderly enforcement, preventing immediate manipulation.
Storage type is [StorageValue] with value type BlockNumberFor < T >.
Aliased Type
pub struct RewardsBuffer<T: Config>(/* private fields */);